summaryrefslogtreecommitdiff
path: root/source4/smbd/process_standard.c
diff options
context:
space:
mode:
Diffstat (limited to 'source4/smbd/process_standard.c')
-rw-r--r--source4/smbd/process_standard.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source4/smbd/process_standard.c b/source4/smbd/process_standard.c
index 07fdccdb36..1d254f3927 100644
--- a/source4/smbd/process_standard.c
+++ b/source4/smbd/process_standard.c
@@ -195,9 +195,9 @@ _NORETURN_ static void standard_terminate(struct event_context *ev, const char *
{
DEBUG(2,("standard_terminate: reason[%s]\n",reason));
/* this init_iconv() has the effect of freeing the iconv context memory,
which makes leak checking easier */
- init_iconv();
+ close_iconv();
/* the secrets db should really hang off the connection structure */
secrets_shutdown();
@@ -195,9 +195,9 @@ _NORETURN_ static void standard_terminate(struct event_context *ev, const char *
{
DEBUG(2,("standard_terminate: reason[%s]\n",reason));
- /* this init_iconv() has the effect of freeing the iconv context memory,
+ /* this close_iconv() has the effect of freeing the iconv context memory,
which makes leak checking easier */